@@ -681,7 +681,7 @@ def get_soup(url, parser='html.parser', ignore_errs=True, **kwargs):
         rurl = normalize(url, True, True, True)
         with requests.get(rurl, **kwargs) as response:
             # Screw weird ascii pages
-            soup = BeautifulSoup(response.content, parser)
+            soup = BeautifulSoup(response.content.decode("utf-8"), parser)
         return soup
     except Exception as e:
         if ignore_errs:
